@@ -3,7 +3,7 @@ package Crypt::JWT;
 use strict;
 use warnings;
 
-our $VERSION = '0.010';
+our $VERSION = '0.011';
 
 use Exporter 'import';
 our %EXPORT_TAGS = ( all => [qw(decode_jwt encode_jwt)] );
@@ -12,7 +12,7 @@ our @EXPORT = qw();
 
 use Carp;
 use MIME::Base64 qw(decode_base64url encode_base64url);
-use JSON qw(decode_json encode_json);
+use JSON::MaybeXS qw(decode_json encode_json);
 use Crypt::PK::RSA;
 use Crypt::PK::ECC;
 use Crypt::PRNG qw(random_bytes);
